@@ -9,11 +9,11 @@ use vars qw(
 );
 use POSIX;
 use Socket;
-#use AutoLoader 'AUTOLOAD';
+use AutoLoader 'AUTOLOAD';
 require Exporter;
 @ISA = qw(Exporter);
 
-$VERSION = do { my @r = (q$Revision: 0.08 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.09 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
 	open_UDP
@@ -38,8 +38,8 @@ $TCP = getprotobyname('tcp');
 
 sub DESTROY {};
 
-#1;
-#__END__
+1;
+__END__
 
 =head1 NAME
 
